/*
  $Id: ClassLabel.java,v 1.2 2008/11/29 01:34:33 h2b Exp $

  Copyright (C) 2008 Hans-Hermann Bode, Berlin, Germany (h2b.de)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2,
  as published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package de.h2b.basis;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.lang.annotation.ElementType;

/**
 * An annotation type for putting certain information into a class file.
 * There are a copyright and an identifier element that can be used
 * appropriately. Both have a default empty-string value, respectively, so
 * that one is able to use one or both of them (or none, although this wouldn't
 * make too much sense).
 * <p>
 * The retention policy for the annotation is to be recorded in the class
 * file by the compiler but need not be retained by the VM at run time.
 * (This is the default behavior.)
 * <p>
 * The annotation is targeted for class, interface (including annotation
 * type), or enum declaration.
 *
 * @since h2basis 0.0.1
 * @author h2b
 * @version $Revision: 1.2 $, $Date: 2008/11/29 01:34:33 $
 */
@ClassLabel(
    copyright="Copyright (C) 2008 Hans-Hermann Bode",
    ident="$Id: ClassLabel.java,v 1.2 2008/11/29 01:34:33 h2b Exp $"
)
@Documented
@Retention(RetentionPolicy.CLASS)
@Target(ElementType.TYPE)
public @interface ClassLabel {

    /**
     * To be used for a copyright notification.
     *
     * @return the copyright notification
     */
    String copyright() default "";

    /**
     * To be used for an identifier. Typically this may be some string
     * generated by keyword substitution from a version control system.
     *
     * @return the identifier
     */
    String ident() default "";
}
