/*
  $Id: HtmlUtil.java,v 1.2 2008/11/29 01:34:33 h2b Exp $

  Copyright (C) 2008 Hans-Hermann Bode, Berlin, Germany (h2b.de)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2,
  as published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package de.h2b.taglets;

import de.h2b.basis.ClassLabel;

/**
 * A utility class that provides some static methods to produce certain HTML
 * output.
 *
 * @since h2taglets 0.1
 * @author h2b
 * @version $Revision: 1.2 $, $Date: 2008/11/29 01:34:33 $
 */
@ClassLabel(
	    copyright="Copyright (C) 2008 Hans-Hermann Bode",
	    ident="$Id: HtmlUtil.java,v 1.2 2008/11/29 01:34:33 h2b Exp $"
	)
public class HtmlUtil {

//Class Methods ---------------------------------------------------------------

    /**
     * Produces an HTML anchor with given name around a text.
     *
     * @since h2taglets 0.1
     * @param name the name of the anchor
     * @param text the surrounded text
     */
    public static String anchor(String name, String text) {
    	return "<a name=\"" + name + "\" id=\"" + name + "\">" + text + "</a>";
    }

    /**
     * Produces a local HTML reference to an anchor with given name around a
     * text.
     *
     * @since h2taglets 0.1
     * @param name the name of the anchor
     * @param text the surrounded text
     */
    public static String href(String name, String text) {
    	return "<a href=\"#" + name + "\">" + text + "</a>";
    }

//Private Constructors --------------------------------------------------------

    /**
     * Does not allow construction from outside.
     *
     * @since h2taglets 0.1
     */
    private HtmlUtil () {
    	super();
    }

//End -------------------------------------------------------------------------
}
