/*
  $Id: InlineTaglet.java,v 1.4 2008/12/14 17:05:37 h2b Exp $

  Copyright (C) 2008 Hans-Hermann Bode, Berlin, Germany (h2b.de)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2,
  as published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package de.h2b.taglets;

import de.h2b.basis.ClassLabel;
import com.sun.tools.doclets.Taglet;    // Taglet API
import com.sun.javadoc.*;               // Doclet API

/**
 * An abstract class that represents a Javadoc inline taglet. It implements all
 * {@code in...} methods of {@link Taglet} so that it can be used in
 * documentation for all program elements.
 *
 * @since h2taglets 0.1
 * @author h2b
 * @version $Revision: 1.4 $, $Date: 2008/12/14 17:05:37 $
 */
@ClassLabel(
    copyright="Copyright (C) 2008 Hans-Hermann Bode",
    ident="$Id: InlineTaglet.java,v 1.4 2008/12/14 17:05:37 h2b Exp $"
)
public abstract class InlineTaglet implements Taglet {

//Public Instance Methods -----------------------------------------------------

    /**
     * Returns the name of this custom tag.
     *
     * @return taglet's name
     * @since h2taglets 0.1
     */
    public abstract String getName();

    /**
     * Will return false since it is an inline tag.
     *
     * @return <code>false</code>
     * @since h2taglets 0.1
     */
    public boolean inField() {
        return false;
    }

    /**
     * Will return false since it is an inline tag.
     *
     * @return <code>false</code>
     * @since h2taglets 0.1
     */
    public boolean inConstructor() {
        return false;
    }

    /**
     * Will return false since it is an inline tag.
     *
     * @return <code>false</code>
     * @since h2taglets 0.1
     */
    public boolean inMethod() {
        return false;
    }

    /**
     * Will return false since it is an inline tag.
     *
     * @return <code>false</code>
     * @since h2taglets 0.1
     */
    public boolean inOverview() {
        return false;
    }

    /**
     * Will return false since it is an inline tag.
     *
     * @return <code>false</code>
     * @since h2taglets 0.1
     */
    public boolean inPackage() {
        return false;
    }

    /**
     * Will return false since it is an inline tag.
     *
     * @return <code>false</code>
     * @since h2taglets 0.1
     */
    public boolean inType() {
        return false;
    }

    /**
     * Will return true since it is an inline tag.
     *
     * @return <code>true</code>
     * @since h2taglets 0.1
     */
    public boolean isInlineTag() {
        return true;
    }

    /**
     * Given the <code>Tag</code> representation of this custom
     * tag, return its string representation.
     *
     * @param tag   the <code>Tag</code> representation of this custom tag
     * @since h2taglets 0.1
     */
    public abstract String toString(Tag tag);

    /**
     * This method should not be called since arrays of inline tags do not
     * exist.  Method {@link #toString(Tag)} should be used to convert this
     * inline tag to a string.
     *
     * @param tags the array of <code>Tag</code>s representing this custom
     *             tag
     * @since h2taglets 0.1
     */
    public String toString(Tag[] tags) {
        return null;
    }

//End -------------------------------------------------------------------------
}
