/*
  $Id: CrossRefMapTest.java,v 1.5 2008/11/29 01:34:33 h2b Exp $

  Copyright (C) 2008 Hans-Hermann Bode, Berlin, Germany (h2b.de)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2,
  as published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package de.h2b.taglets;

import static org.junit.Assert.*;
import org.junit.*;
import java.io.File;
import de.h2b.basis.ClassLabel;

/**
 * A test class for {@link CrossRefMap}.
 *
 * @see CrossRefMap
 *
 * @author h2b
 * @version $Revision: 1.5 $, $Date: 2008/11/29 01:34:33 $

*/
@ClassLabel(
    copyright="Copyright (C) 2008 Hans-Hermann Bode",
    ident="$Id: CrossRefMapTest.java,v 1.5 2008/11/29 01:34:33 h2b Exp $"
)
public class CrossRefMapTest {

//Fields ----------------------------------------------------------------------

    /**
     * Pathname of test file.
     */
	protected static final File testFile =
		  new File("/tmp/CrossRefMapTest.aux");

    //Test keys
    private String key1 = "key1";
    private String key2 = "key2";

//Test Methods ----------------------------------------------------------------

	/**
	 * Test if resulting tables for different keys are different.
     *
     * @see CrossRefMap#getTable
	 */
	@Test
	public void testGetTable1() {
		CrossRefTable t1 = CrossRefMap.getInstance().getTable(key1);
		CrossRefTable t2 = CrossRefMap.getInstance().getTable(key2);
		assertTrue("tables should be different", t1!=t2);
	}

	/**
	 * Test if resulting tables for identical keys are identical.
     *
     * @see CrossRefMap#getTable
	 */
	@Test
	public void testGetTable2() {
		CrossRefTable t1a = CrossRefMap.getInstance().getTable(key1);
		CrossRefTable t1b = CrossRefMap.getInstance().getTable(key1);
		assertTrue("tables should be identical", t1a==t1b);
	}

	/**
	 * Test if map is stored in file correctly.
     *
     * @see CrossRefMap#load
     * @see CrossRefMap#save
	 */
	@Test
	public void testSaveLoad() {
		//add some tables and references and save file
		CrossRefTable t1 = CrossRefMap.getInstance().getTable(key1);
		CrossRefTable t2 = CrossRefMap.getInstance().getTable(key2);
	    String r1 = "ref1";
	    String r2 = "ref2";
	    String r3 = "ref3";
	    String r4 = "ref4";
		CrossRefMap.getInstance().save(testFile);
    	t1.getIndex(r1);
    	t1.getIndex(r2);
    	t2.getIndex(r3);
		CrossRefMap.getInstance().save(testFile);
    	t2.getIndex(r4); //intentionally not saved
    	//reload file
		CrossRefMap.getInstance().load(testFile);
		assertTrue("stored table should return correct index",
				CrossRefMap.getInstance().getTable(key1).getReference(r1).
				equals("1"));
		assertTrue("stored table should return correct index",
				CrossRefMap.getInstance().getTable(key1).getReference(r2).
				equals("2"));
		assertTrue("stored table should return correct index",
				CrossRefMap.getInstance().getTable(key2).getReference(r3).
				equals("1"));
		assertTrue("stored table should not return unsaved index",
				CrossRefMap.getInstance().getTable(key2).getReference(r4).
				equals(r4));
	}

//End -------------------------------------------------------------------------
}
