/*
  $Id: CrossRefTableTest.java,v 1.3 2008/11/29 01:34:33 h2b Exp $

  Copyright (C) 2008 Hans-Hermann Bode, Berlin, Germany (h2b.de)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2,
  as published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package de.h2b.taglets;

import static org.junit.Assert.*;
import org.junit.*;
import de.h2b.basis.ClassLabel;

/**
 * A test class for {@link CrossRefTable}.
 *
 * @see CrossRefTable
 *
 * @author h2b
 * @version $Revision: 1.3 $, $Date: 2008/11/29 01:34:33 $

*/
@ClassLabel(
    copyright="Copyright (C) 2008 Hans-Hermann Bode",
    ident="$Id: CrossRefTableTest.java,v 1.3 2008/11/29 01:34:33 h2b Exp $"
)
public class CrossRefTableTest {

//Fields ----------------------------------------------------------------------

    /**
     * Pathname of test file.
     */
	protected static final String testFilePath = "/tmp/CrossRefTableTest.aux";

    //Test table
    private CrossRefTable testTable;

    //Test keys
    private String key1 = "key1";
    private String key2 = "key2";
    private String key3 = "key3";

//Fixtures --------------------------------------------------------------------

    /**
     * Sets up the test fixture.
     * (Called before every test-case method.)
     */
    @Before
    public void setUp() {
    	testTable = new CrossRefTable();
    	testTable.getIndex(key1);
    	testTable.getIndex(key2);
    }

    /**
     * Tears down the test fixture.
     * (Called after every test-case method.)
     */
    @After
    public void tearDown() {
    	testTable = null;
    }

//Test Methods ----------------------------------------------------------------

	/**
	 * Test if correct index is returned for existing keys.
     *
     * @see CrossRefTable#getIndex
	 */
	@Test
	public void testGetIndex1() {
		assertTrue("existing key should have correct index",
				   testTable.getIndex(key1).equals("1"));
		assertTrue("existing key should have correct index",
				   testTable.getIndex(key2).equals("2"));
	}

	/**
	 * Test if new key is added with correct index.
     *
     * @see CrossRefTable#getIndex
	 */
	@Test
	public void testGetIndex2() {
		assertTrue("new key should be appended to table",
				   testTable.getIndex(key3).equals("3"));
	}

	/**
	 * Test if correct index is returned for existing keys.
     *
     * @see CrossRefTable#getReference
	 */
	@Test
	public void testGetReference1() {
		assertTrue("existing key should have correct index",
			       testTable.getReference(key1).equals("1"));
		assertTrue("existing key should have correct index",
			       testTable.getReference(key2).equals("2"));
	}

	/**
	 * Test if new key is returned by itself.
     *
     * @see CrossRefTable#getReference
	 */
	@Test
	public void testGetReference2() {
		assertTrue("new key should not be appended to table",
			       testTable.getReference(key3).equals(key3));
	}

	/**
	 * Test if table is stored in file correctly.
     *
     * @see CrossRefTable#save
	 */
	@Test
	public void testSave() {
		//add some keys and save file
    	testTable = new CrossRefTable(testFilePath);
    	testTable.getIndex(key1);
    	testTable.getIndex(key2);
    	testTable.getIndex(key3);
    	testTable.save();
    	//reload file
    	testTable = new CrossRefTable(testFilePath);
		assertTrue("stored key should have correct index",
			       testTable.getReference(key1).equals("1"));
		assertTrue("stored key should have correct index",
			       testTable.getReference(key2).equals("2"));
		assertTrue("stored key should have correct index",
			       testTable.getReference(key3).equals("3"));
	}

//End -------------------------------------------------------------------------
}
