/*
  $Id: RegistrationTest.java,v 1.2 2008/11/29 01:34:33 h2b Exp $

  Copyright (C) 2008 Hans-Hermann Bode, Berlin, Germany (h2b.de)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2,
  as published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package de.h2b.taglets;

import static org.junit.Assert.*;
import org.junit.*;
import java.util.Map;
import java.util.HashMap;
import com.sun.tools.doclets.internal.toolkit.taglets.Taglet;
import de.h2b.taglets.biblets.*;
import de.h2b.taglets.mathlets.*;
import de.h2b.basis.ClassLabel;

/**
 * A test class for {@link Registration}.
 *
 * @see Registration
 * @author h2b
 * @version $Revision: 1.2 $, $Date: 2008/11/29 01:34:33 $
*/
@ClassLabel(
    copyright="Copyright (C) 2008 Hans-Hermann Bode",
    ident="$Id: RegistrationTest.java,v 1.2 2008/11/29 01:34:33 h2b Exp $"
)
public class RegistrationTest {

//Fields ----------------------------------------------------------------------

    //Test map
	private static Map testMap = new HashMap();

	static {
		Registration.register(testMap);
	}

//Test Methods ----------------------------------------------------------------

	/**
	 * Test if {@link MathTaglet} has been successfully registered to
	 * {@code testMap}.
     *
     * @see Registration#register
     * @see MathTaglet
	 */
	@Test
	public void testMathTagletRegistered() {
		Object t = testMap.get(new MathTaglet().getName());
		assertTrue("map should contain valid MathTaglet",
				(t!=null) && (t instanceof Taglet));
	}

	/**
	 * Test if {@link CiteTaglet} has been successfully registered to
	 * {@code testMap}.
     *
     * @see Registration#register
     * @see CiteTaglet
	 */
	@Test
	public void testCiteTagletRegistered() {
		Object t = testMap.get(new CiteTaglet().getName());
		assertTrue("map should contain valid CiteTaglet",
				(t!=null) && (t instanceof Taglet));
	}

	/**
	 * Test if {@link BiblioTaglet} has been successfully registered to
	 * {@code testMap}.
     *
     * @see Registration#register
     * @see BiblioTaglet
	 */
	@Test
	public void testBiblioTagletRegistered() {
		Object t = testMap.get(new BiblioTaglet().getName());
		assertTrue("map should contain valid BiblioTaglet",
				(t!=null) && (t instanceof Taglet));
	}

//End -------------------------------------------------------------------------
}
